darkhistory.history.reionization.photoheat_rate — DarkHistory documentation

# darkhistory.history.reionization.photoheat_rate

`darkhistory.history.reionization.` `photoheat_rate`(species)

  Photoheating rate.

  Parameters: | species : {‘HI’, ‘HeI’, ‘HeII’}
  Returns: | function Interpolating function which takes redshift as an argument, and returns the photoionization rate of the species in s^-1. See 1801.04931.

#### Previous topic

darkhistory.history.reionization.coll_ion_rate

#### Next topic

darkhistory.history.reionization.photoion_rate

### This Page

Show Source